@@ -13,6 +13,7 @@
 #' You might consider using the Algina, Keselman, & Penfield (2008) approach via the apa.reg.boot.table function
 #'
 #' @examples
+#' \dontrun{
 #' # View top few rows of goggles data set
 #' # from Discovering Statistics Using R
 #' head(album)
@@ -41,7 +42,7 @@
 #' #Interaction product-term test with single regression (i.e., semi-partial correlation focus)
 #' blk1 <- lm(sales ~ adverts + airplay + I(adverts * airplay), data=album)
 #' apa.reg.table(blk1,filename="exInteraction3.doc")
-#'
+#' }
 #' @export
 apa.reg.table<-function(...,filename=NA,table.number=NA, prop.var.conf.level = .95) {
      regression_results_list <- list(...)
@@ -150,9 +151,13 @@ apa.reg.table<-function(...,filename=NA,table.number=NA, prop.var.conf.level = .
                last_block_summary <- cur_block_summary
                last_block_lm <- cur_block_lm
 
+               if (has_beta_cols(block_out_txt) == TRUE & (has_beta_cols(cur_block_out_txt) == FALSE)) {
+                    block_out_txt <- select(block_out_txt, -beta, -beta_CI, -r)
+                    block_out_rtf <- select(block_out_rtf, -beta, -beta_CI, -r)
+               }
+
                block_out_txt <- rbind(block_out_txt,cur_block_out_txt)
                block_out_rtf <- rbind(block_out_rtf,cur_block_out_rtf)
-
           }
      } else {
           block_out_txt <- dplyr::select(block_out_txt, -difference)
@@ -647,3 +652,9 @@ get_delta_R2_blocks <- function(blk2,blk1,summary2,summary1,n, prop_var_conf_lev
      output$deltaR2_pvalue <- deltaR2_p
      return(output)
 }
+
+
+has_beta_cols <- function(df) {
+     return("beta" %in% names(df))
+}
+
